@@ -2,7 +2,7 @@ from django.db import models
 
 
 class Blacklist(models.Model):
-    email = models.EmailField(db_index=True)
+    email = models.EmailField(unique=True)
     created_at = models.DateTimeField(auto_now_add=True)
 
     def __unicode__(self):
@@ -17,7 +17,7 @@ RESULT_CODES = (
 
 class MessageLogManager(models.Manager):
     def log(self, message, result_code):
-        self.create(email=message.to, body=message.message(), result=result_code)
+        self.create(email=message.to[0], body=message.message(), result=result_code)
         
 
 class MessageLog(models.Model):
